# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ThreadBatchStopResultItem(UniversalBaseModel):
    """
    Result for a single thread in batch stop operation.
    """

    error: typing.Optional[str] = pydantic.Field(default=None)
    """
    Error message if stop failed
    """

    success: bool = pydantic.Field()
    """
    Whether the stop was successful
    """

    thread_id: str = pydantic.Field()
    """
    The thread ID
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
